@@ -1,17 +1,18 @@
 # -*- coding: utf-8 -*-
 """Utility methods for marshmallow."""
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import datetime
-from decimal import Decimal, ROUND_HALF_EVEN, Context, Inexact
 import functools
 import inspect
 import json
 import time
 import types
 from calendar import timegm
+from decimal import Decimal, ROUND_HALF_EVEN, Context, Inexact
 from email.utils import formatdate, parsedate
 from pprint import pprint as py_pprint
+import warnings
 
 from marshmallow.compat import basestring, OrderedDict, binary_type, text_type
 
@@ -212,8 +213,7 @@ def from_datestring(datestring):
     if dateutil_available:
         return parser.parse(datestring)
     else:
-        raise RuntimeError('from_datestring requires the python-dateutils to be'
-                           'installed.')
+        raise RuntimeError('from_datestring requires the python-dateutil library')
 
 def from_rfc(datestring, use_dateutil=True):
     """Parse a RFC822-formatted datetime string and return a datetime object.
@@ -261,7 +261,7 @@ def from_iso_date(datestring, use_dateutil=True):
     if dateutil_available and use_dateutil:
         return parser.parse(datestring).date()
     else:
-        return datetime.datetime.strptime(datestring[:10], '%Y-%m-%d')
+        return datetime.datetime.strptime(datestring[:10], '%Y-%m-%d').date()
 
 def ensure_text_type(val):
     if isinstance(val, binary_type):
@@ -309,12 +309,27 @@ def _get_value_for_key(key, obj, default):
     return default
 
 
-def get_func_name(func):
-    """Given a function object, return its name. Handles `functools.partial` objects.
+def get_callable_name(func):
+    """Given a callable, return its name. Handles `functools.partial` objects
+    and class-based callables.
     """
-    if isinstance(func, functools.partial):
+    if inspect.isfunction(func):
+        return func.__name__
+    elif isinstance(func, functools.partial):
         return func.func.__name__
-    return func.__name__
+    else:  # Callable class
+        return func.__class__.__name__
+
+
+def get_func_name(func):
+    """Given a callable, return its name. Handles `functools.partial` objects.
+
+    .. deprecated:: 1.2.0
+        Renamed to :func:`get_callable_name`.
+    """
+    warnings.warn('get_func_name was renamed to get_callable_name. get_func_name '
+                  'will be removed in version 2.0', DeprecationWarning)
+    return get_callable_name(func)
 
 
 def callable_or_raise(obj):
